@@ -253,27 +253,38 @@ class BigQuerySourceConnector(C8Connector):
     def samples(self, integration: dict) -> list[Sample]:
         """Fetch sample data using the provided configurations."""
         config = self.get_config(integration)
+        LOGGER.info('Debugging 1 %s', config)
         try:
             config = source.create_credentials_file(config)
+            LOGGER.info('Debugging 2 %s', config)
             streams = discover(config)['streams']
+            LOGGER.info('Debugging 3 %s', streams)
             results = []
+            LOGGER.info('Debugging 4 %s', results)
             for stream in streams:
                 s_attribs = []
+                LOGGER.info('Debugging 5 %s', s_attribs)
                 s_schema = stream['schema']
+                LOGGER.info('Debugging 6 %s', s_schema)
 
                 data = fetch_samples(config, stream)[:10]
+                LOGGER.info('Debugging 7 %s', data)
                 # Appending _ to keys for preserving values of reserved keys in source data
                 reserved_keys = ['_key', '_id', '_rev']
                 if stream['metadata'][0]['metadata'].get('table-key-properties'):
                     key_properties = stream['metadata'][0]['metadata'].get('table-key-properties')
+                    LOGGER.info('Debugging 8 %s', key_properties)
                     if key_properties[0] == '_key':
                         reserved_keys.remove('_key')
                 s_schema['properties'] = modify_reserved_keys(s_schema['properties'], reserved_keys)
+                LOGGER.info('Debugging 9 %s', s_schema)
 
                 for k, v in s_schema['properties'].items():
                     t = v['type'][-1]
+                    LOGGER.info('Debugging 10 %s', t)
                     s_attribs.append(SchemaAttribute(k, self.get_attribute_type(t)))
                 schema = Schema(stream['stream'], s_attribs)
+                LOGGER.info('Debugging 11 %s', schema)
                 results.append(Sample(
                     schema=schema,
                     data=data)
